Class: Aws::B2bi::Types::WrapOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::B2bi::Types::WrapOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-b2bi/types.rb
Overview
Contains options for wrapping (line folding) in X12 EDI files. Wrapping controls how long lines are handled in the EDI output.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#line_length ⇒ Integer
Specifies the maximum length of a line before wrapping occurs.
-
#line_terminator ⇒ String
Specifies the character sequence used to terminate lines when wrapping.
-
#wrap_by ⇒ String
Specifies the method used for wrapping lines in the EDI output.
Instance Attribute Details
#line_length ⇒ Integer
Specifies the maximum length of a line before wrapping occurs. This
value is used when wrapBy is set to LINE_LENGTH.
2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-b2bi/types.rb', line 2812 class WrapOptions < Struct.new( :wrap_by, :line_terminator, :line_length) SENSITIVE = [] include Aws::Structure end |
#line_terminator ⇒ String
Specifies the character sequence used to terminate lines when wrapping. Valid values:
-
CRLF: carriage return and line feed -
LF: line feed) -
CR: carriage return
2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-b2bi/types.rb', line 2812 class WrapOptions < Struct.new( :wrap_by, :line_terminator, :line_length) SENSITIVE = [] include Aws::Structure end |
#wrap_by ⇒ String
Specifies the method used for wrapping lines in the EDI output. Valid values:
-
SEGMENT: Wraps by segment. -
ONE_LINE: Indicates that the entire content is on a single line.When you specify ONE_LINE, do not provide either the line length nor the line terminator value. -
LINE_LENGTH: Wraps by character count, as specified bylineLengthvalue.
2812 2813 2814 2815 2816 2817 2818 |
# File 'lib/aws-sdk-b2bi/types.rb', line 2812 class WrapOptions < Struct.new( :wrap_by, :line_terminator, :line_length) SENSITIVE = [] include Aws::Structure end |